==> indigitall_flutter_plugin-2.0.2.tar.gz: ios/Classes/utils/IndigitallInAppFParse.m <==
//
//  IndigitallInAppFParse.m
//  indigitall_inapp_flutter_plugin
//
//  Created by indigitall on 17/1/23.
//

#import "IndigitallInAppFParse.h"

@implementation IndigitallInAppFParse


+ (void) jsonFromInApp:(INInApp *)inApp  withResult: (FlutterResult _Nonnull) result {
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    NSMutableDictionary *inAppDict = [[NSMutableDictionary alloc]init];
    if (inApp != nil) {
        obj = [@{
            @"inAppId" : @(inApp.inAppId)?: 0,
            @"InAppWidth": @(inApp.inAppWidth)?: 0,
            @"InAppHeight" : @(inApp.inAppHeight)?: 0,
            @"lastVersionId": @(inApp.lastVersionId)?: 0,
            @"code": inApp.code  ?: @"",
            @"properties" : [self jsonFromInAppProperties:inApp.properties]?: nil,
            @"inAppShow" : [self jsonFromInAppShow: inApp.inAppShow]?: nil,
            @"showOnce" : @(inApp.showOnce)?: 0,
            @"expiredDate": inApp.expiredDate  ?: @"",
            @"creationDate": inApp.creationDate  ?: @"",
            @"cacheTtl": @(inApp.cacheTtl)?: 0,
            @"customData": inApp.customData?: @"",
            @"version": @(inApp.version)?: 0
        } mutableCopy];
    }
    [inAppDict setValue:[obj copy] forKey:@"callbackGetInApp"];
    result([inAppDict mutableCopy]);
}

+ (NSDictionary *)jsonFromInAppShow: (INInAppShow *)inAppShow{
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    if (inAppShow != nil) {
        obj = [@{
            @"wasDismissed" : @(inAppShow.wasDismissed),
            @"timesShowed": @(inAppShow.timesShowed),
            @"timesClicked" : @(inAppShow.timesClicked)
        } mutableCopy];
    }
    return [obj copy];
}

+ (NSDictionary *)jsonFromInAppProperties: (INInAppProperties *)properties{
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    if (properties != nil) {
        obj = [@{
            @"contentUrl" : properties.InAppContentUrl.absoluteString ?: @"",
            @"numberOfShows": @(properties.numberOfShows),
            @"numberOfClicks" : @(properties.numberOfClicks),
            @"dismissForever": @(properties.dismissForever),
            @"showTime": @(properties.showTime),
            @"action" : [self jsonFromAction:properties.action],
            @"borderRadius" : @(properties.layout.borderRadius),
        } mutableCopy];
    }
    return [obj copy];
}

+ (NSDictionary *)jsonFromAction: (INCoreAction *)action{
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    if (action != nil) {
        obj = [@{
            @"app" : action.app ?: @"",
            @"url": action.url ?: @"",
            @"share" : action.share ?: @"",
            @"call": action.call ?: @"",
            @"market": action.market ?: @"",
            @"noAction" : action.noAction ?: @"",
            @"wallet" : action.wallet ?: @"",
            @"type" : @(action.type),
        } mutableCopy];
    }
    return [obj copy];
}

+ (void) jsonArrayFromtopics: (NSArray<INInAppTopic *>*) topics withKey:(NSString *)key withResult: (FlutterResult _Nonnull) result{
    NSArray<NSDictionary *>* array = [NSArray new];
    @try{
        for (int i=0;i<topics.count;i++){
            NSDictionary *obj = [[NSDictionary alloc]init];
            obj = @{
            @"code" : topics[i].code ?: @"",
            @"name": topics[i].name ?: @"",
            @"parentCode" : topics[i].parentCode ?: @"",
            @"visible" :@(topics[i].visible) ?: false,
            @"subscribed" :@(topics[i].subscribed) ?: false
            };
            array = [array arrayByAddingObject:obj];
            
        }
    } @catch (NSException *exception) {
        NSLog(@"Error jsonArrayFromtopics %@", exception);
    }
    [self resultFromTopic:array key:key withResult:result];
}

+ (void) resultFromTopicString: (NSArray<NSString *>*) topics withKey: (NSString *) key withResult: (FlutterResult _Nonnull) result {
    NSMutableDictionary *dict = [NSMutableDictionary new];
    [dict setValue:topics forKey:key];
    result([dict copy]);
}

+ (void) resultFromTopic: (NSArray<NSDictionary *>*) topics key: (NSString *) key withResult: (FlutterResult _Nonnull) result {
    NSMutableDictionary *dict = [NSMutableDictionary new];
    [dict setValue:topics forKey:key];
    result([dict copy]);
}

+ (void) jsonFromInAppError: (INInAppError *)error withResult: (FlutterResult _Nonnull) result {
    result([FlutterError errorWithCode:[NSString stringWithFormat:@"%u",error.errorCode] message:error.message details:nil]);
}

+ (void) setErrorWithErrorCode:(NSString *)code withMessage: (NSString *)message withResult: (FlutterResult _Nonnull) result {
    result([FlutterError errorWithCode:code message:message details:nil]);
}

+ (void) jsonFromError: (INError *)error withResult: (FlutterResult _Nonnull) result {
    result([FlutterError errorWithCode:[NSString stringWithFormat:@"%u",error.errorCode] message:error.message details:nil]);
}
@end

==> indigitall_flutter_plugin-2.5.1.tar.gz: ios/Classes/utils/IndigitallInAppFParse.m <==
//
//  IndigitallInAppFParse.m
//  indigitall_inapp_flutter_plugin
//
//  Created by indigitall on 17/1/23.
//

#import "IndigitallInAppFParse.h"

@implementation IndigitallInAppFParse


+ (void) jsonFromInApp:(INInApp *)inApp  withResult: (FlutterResult _Nonnull) result {
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    NSMutableDictionary *inAppDict = [[NSMutableDictionary alloc]init];
    if (inApp != nil) {
        obj = [@{
            @"inAppId" : @(inApp.inAppId)?: 0,
            @"InAppWidth": @(inApp.inAppWidth)?: 0,
            @"InAppHeight" : @(inApp.inAppHeight)?: 0,
            @"lastVersionId": @(inApp.lastVersionId)?: 0,
            @"code": inApp.code  ?: @"",
            @"properties" : [self jsonFromInAppProperties:inApp.properties]?: nil,
            @"inAppShow" : [self jsonFromInAppShow: inApp.inAppShow]?: nil,
            @"showOnce" : @(inApp.showOnce)?: 0,
            @"expiredDate": inApp.expiredDate  ?: @"",
            @"creationDate": inApp.creationDate  ?: @"",
            @"cacheTtl": @(inApp.cacheTtl)?: 0,
            @"customData": inApp.customData?: @"",
            @"version": @(inApp.version)?: 0,
            @"filters" :[self jsonFromInAppFilters: inApp.filters]?: nil,
            @"name" :inApp.name ?: @""
        } mutableCopy];
    }
    [inAppDict setValue:[obj copy] forKey:@"callbackGetInApp"];
    result([inAppDict mutableCopy]);
}

+ (NSDictionary *)jsonFromInAppFilters: (INInAppFilters *) filters {
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    if (filters != nil) {
        obj = [@{
            @"platforms" : filters.platforms?: @"",
            @"areas": filters.areas?: @"",
            @"audience" : filters.audience?: @"",
            @"topics": filters.topics.toJson ?: @"",
            @"externalApps": filters.externalApps ?: @"",
            @"deviceCodes" : filters.deviceCodes?: @"",
            @"deviceCodesActive" : @(filters.deviceCodesActive) ?: false,
            @"deviceTypes": filters.deviceTypes?: @"",
            @"browserTypes" : filters.browserTypes?: @"",
            @"activePushDevices" : @(filters.activePushDevices) ?: false
        } mutableCopy];
    }
    return obj;
}

+ (NSDictionary *)jsonFromInAppShow: (INInAppShow *)inAppShow{
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    if (inAppShow != nil) {
        obj = [@{
            @"wasDismissed" : @(inAppShow.wasDismissed),
            @"timesShowed": @(inAppShow.timesShowed),
            @"timesClicked" : @(inAppShow.timesClicked)
        } mutableCopy];
    }
    return [obj copy];
}

+ (NSDictionary *)jsonFromInAppProperties: (INInAppProperties *)properties{
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    if (properties != nil) {
        obj = [@{
            @"contentUrl" : properties.InAppContentUrl.absoluteString ?: @"",
            @"numberOfShows": @(properties.numberOfShows),
            @"numberOfClicks" : @(properties.numberOfClicks),
            @"dismissForever": @(properties.dismissForever),
            @"showTime": @(properties.showTime),
            @"action" : [self jsonFromAction:properties.action],
            @"borderRadius" : @(properties.layout.borderRadius),
        } mutableCopy];
    }
    return [obj copy];
}

+ (NSDictionary *)jsonFromAction: (INCoreAction *)action{
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    if (action != nil) {
        obj = [@{
            @"app" : action.app ?: @"",
            @"url": action.url ?: @"",
            @"share" : action.share ?: @"",
            @"call": action.call ?: @"",
            @"market": action.market ?: @"",
            @"noAction" : action.noAction ?: @"",
            @"wallet" : action.wallet ?: @"",
            @"webview" : action.webview ?: @"",
            @"type" : @(action.type),
        } mutableCopy];
    }
    return [obj copy];
}

+ (void) jsonArrayFromtopics: (NSArray<INInAppTopic *>*) topics withKey:(NSString *)key withResult: (FlutterResult _Nonnull) result{
    NSArray<NSDictionary *>* array = [NSArray new];
    @try{
        for (int i=0;i<topics.count;i++){
            NSDictionary *obj = [[NSDictionary alloc]init];
            obj = @{
            @"code" : topics[i].code ?: @"",
            @"name": topics[i].name ?: @"",
            @"parentCode" : topics[i].parentCode ?: @"",
            @"visible" :@(topics[i].visible) ?: false,
            @"channel" :@(topics[i].channel) ?: @"inapp",
            @"subscribed" :@(topics[i].subscribed) ?: false
            };
            array = [array arrayByAddingObject:obj];
            
        }
    } @catch (NSException *exception) {
        NSLog(@"Error jsonArrayFromtopics %@", exception);
    }
    [self resultFromTopic:array key:key withResult:result];
}

+ (void) resultFromTopicString: (NSArray<NSString *>*) topics withKey: (NSString *) key withResult: (FlutterResult _Nonnull) result {
    NSMutableDictionary *dict = [NSMutableDictionary new];
    [dict setValue:topics forKey:key];
    result([dict copy]);
}

+ (void) resultFromTopic: (NSArray<NSDictionary *>*) topics key: (NSString *) key withResult: (FlutterResult _Nonnull) result {
    NSMutableDictionary *dict = [NSMutableDictionary new];
    [dict setValue:topics forKey:key];
    result([dict copy]);
}

+ (void) jsonFromInAppError: (INInAppError *)error withResult: (FlutterResult _Nonnull) result {
    result([FlutterError errorWithCode:[NSString stringWithFormat:@"%u",error.errorCode] message:error.message details:nil]);
}

+ (void) setErrorWithErrorCode:(NSString *)code withMessage: (NSString *)message withResult: (FlutterResult _Nonnull) result {
    result([FlutterError errorWithCode:code message:message details:nil]);
}

+ (void) jsonFromError: (INError *)error withResult: (FlutterResult _Nonnull) result {
    result([FlutterError errorWithCode:[NSString stringWithFormat:@"%u",error.errorCode] message:error.message details:nil]);
}
@end
